@@ -30,6 +30,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "greeterapp.h"
 
 #include <config-kscreenlocker.h>
+#include <kscreenlocker_greet_logging.h>
+
 #if HAVE_SYS_PRCTL_H
 #include <sys/prctl.h>
 #endif
@@ -54,9 +56,12 @@ static void signalHandler(int signum)
         // exit gracefully to not leave behind screensaver processes (bug#224200)
         // return exit code 1 to indicate that a valid password was not entered,
         // to prevent circumventing the password input by sending a SIGTERM
+
+        qCDebug(KSCREENLOCKER_GREET) << "Greeter received SIGTERM. Will exit with error.";
         instance->exit(1);
         break;
       case SIGUSR1:
+        qCDebug(KSCREENLOCKER_GREET) << "Greeter received SIGUSR1. Will lock immediately.";
         instance->lockImmediately();
         break;
     }
@@ -73,6 +78,8 @@ int main(int argc, char* argv[])
     procctl(P_PID, getpid(), PROC_TRACE_CTL, &mode);
 #endif
 
+    qCDebug(KSCREENLOCKER_GREET) << "Greeter is starting up.";
+
     KLocalizedString::setApplicationDomain("kscreenlocker_greet");
 
     // explicitly disable input methods as it makes it impossible to unlock, see BUG 306932
